Module tui

Module tui 

Functions

run_tui
Run the TUI directly into the main browse view. Called when a path is already given on the command line.
run_tui_welcome
Run the TUI starting from the welcome/input screen. Called when no path is given on the command line.