Module tui
skelecode
1.0.0
Module tui
Module Items
Functions
In crate skelecode
skelecode
Module
tui
Functions

run_tui
Run the TUI directly into the main browse view. Called when a path is already given on the command line.
run_
tui_
welcome
Run the TUI starting from the welcome/input screen. Called when no path is given on the command line.